@@ -4,9 +4,10 @@ import re
 import subprocess
 import sys
 
-import html2text
 import pytest
 
+import html2text
+
 skip = object()
 
 
@@ -101,6 +102,11 @@ def generate_testdata():
             cmdline_args.append("--reference-links")
             func_args = skip
 
+        if base_fn.startswith("no_mailto_links"):
+            module_args["ignore_mailto_links"] = True
+            cmdline_args.append("--ignore-mailto-links")
+            func_args = skip
+
         if base_fn.startswith("no_wrap_links"):
             module_args["wrap_links"] = False
             cmdline_args.append("--no-wrap-links")
@@ -121,6 +127,11 @@ def generate_testdata():
             cmdline_args.append("--wrap-list-items")
             func_args = skip
 
+        if base_fn.startswith("wrap_tables"):
+            module_args["wrap_tables"] = True
+            cmdline_args.append("--wrap-tables")
+            func_args = skip
+
         if base_fn == "inplace_baseurl_substitution.html":
             module_args["baseurl"] = "http://brettterpstra.com"
             module_args["body_width"] = 0
@@ -129,6 +140,11 @@ def generate_testdata():
             # CLI doesn't support baseurl.
             cmdline_args = skip
 
+        if base_fn in ["sup_tag.html", "sub_tag.html"]:
+            module_args["include_sup_sub"] = True
+            cmdline_args.append("--include-sup-sub")
+            func_args = skip
+
         yield fn, module_args, cmdline_args, func_args
 
 
@@ -163,11 +179,11 @@ def test_module(fn, module_args):
     for k, v in module_args.items():
         setattr(h, k, v)
 
-    result = get_baseline(fn)
+    expected = get_baseline(fn)
     with open(fn) as inf:
         actual = cleanup_eol(inf.read())
         actual = h.handle(actual)
-    assert result == actual
+    assert actual.rstrip() == expected.rstrip()
 
 
 @pytest.mark.parametrize("fn,cmdline_args", generate_command_testdata())
@@ -184,22 +200,21 @@ def test_command(fn, cmdline_args):
 
     cmd += [fn]
 
-    result = get_baseline(fn)
+    expected = get_baseline(fn)
     out = subprocess.check_output(cmd)
 
     actual = out.decode()
 
     actual = cleanup_eol(actual)
-
-    assert result == actual
+    assert actual.rstrip() == expected.rstrip()
 
 
 @pytest.mark.parametrize("fn,func_args", generate_function_testdata())
 def test_function(fn, func_args):
     with open(fn) as inf:
         actual = html2text.html2text(inf.read(), **func_args)
-    result = get_baseline(fn)
-    assert result == actual
+    expected = get_baseline(fn)
+    assert actual.rstrip() == expected.rstrip()
 
 
 def get_baseline_name(fn):
@@ -224,4 +239,13 @@ def test_tag_callback():
         'this is a <b>txt</b> and this is a <b class="skip">with text</b> and '
         "some <i>italics</i> too."
     )
-    assert ret == ("this is a txt and this is a with text and some _italics_ too.\n\n")
+    assert ret == "this is a txt and this is a with text and some _italics_ too.\n\n"
+
+
+def test_strong_emptied() -> None:
+    """When strong is being set to empty, it should not mark it."""
+    h = html2text.HTML2Text()
+    h.emphasis_mark = "_"
+    h.strong_mark = ""
+    string = "A <b>B</b> <i>C</i>."
+    assert h.handle(string) == "A B _C_.\n\n"
